@@ -1,24 +1,24 @@
 # -*- mode: ruby; coding: us-ascii; -*-
 
-require 'rubygems'
+require "rubygems"
 
 begin
-  gem 'rake'
+  gem "rake"
 rescue Gem::LoadError
   warn "Using the crusty system installed rake... you probably want to upgrade"
 end
-require 'rake'
-require 'rake/testtask'
-require 'rbconfig'
+require "rake"
+require "rake/testtask"
+require "rbconfig"
 
 begin
-  require 'psych'
+  require "psych"
 rescue LoadError
   # do nothing
 end
-require 'yaml'
+require "yaml"
 
-require 'hoe/rake'
+require "hoe/rake"
 
 ##
 # Hoe is a simple rake/rubygems helper for project Rakefiles. It helps
@@ -91,7 +91,7 @@ class Hoe
   include Rake::DSL if defined?(Rake::DSL)
 
   # duh
-  VERSION = "3.8.0"
+  VERSION = "3.14.2"
 
   @@plugins = [:clean, :debug, :deps, :flay, :flog, :newb, :package,
                :publish, :gemcutter, :signing, :test]
@@ -101,28 +101,28 @@ class Hoe
   ##
   # Used to add extra flags to RUBY_FLAGS.
 
-  RUBY_DEBUG = ENV['RUBY_DEBUG']
+  RUBY_DEBUG = ENV["RUBY_DEBUG"]
 
-  default_ruby_flags = "-w -I#{%w(lib bin test .).join(File::PATH_SEPARATOR)}" +
-    (RUBY_DEBUG ? " #{RUBY_DEBUG}" : '')
+  default_ruby_flags = "-w -I#{%w[lib bin test .].join(File::PATH_SEPARATOR)}" +
+    (RUBY_DEBUG ? " #{RUBY_DEBUG}" : "")
 
   ##
   # Used to specify flags to ruby [has smart default].
 
-  RUBY_FLAGS = ENV['RUBY_FLAGS'] || default_ruby_flags
+  RUBY_FLAGS = ENV["RUBY_FLAGS"] || default_ruby_flags
 
   ##
   # Default configuration values for .hoerc. Plugins should populate
   # this on load.
 
   DEFAULT_CONFIG = {
-    "exclude" => /tmp$|CVS|\.svn|TAGS|extconf.h|\.o$|\.log$/,
+    "exclude" => /\/tmp\/|CVS|\.svn|\.git|TAGS|extconf.h|\.bundle$|\.o$|\.log$/,
   }
 
   ##
   # True if you're a masochistic developer. Used for building commands.
 
-  WINDOZE = RbConfig::CONFIG['host_os'] =~ /mswin|mingw/
+  WINDOZE = RbConfig::CONFIG["host_os"] =~ /mswin|mingw/
 
   ##
   # *MANDATORY*: The author(s) of the package. (can be array)
@@ -211,9 +211,6 @@ class Hoe
 
   attr_accessor :group_name
 
-  alias :rubyforge_name  :group_name  # Deprecated. Use #group_name.
-  alias :rubyforge_name= :group_name= # Deprecated. Use #group_name=.
-
   ##
   # The Gem::Specification.
 
@@ -346,11 +343,11 @@ class Hoe
   # Test klass names are same as Klass with Test prepended to each part.
 
   def self.normalize_names project # :nodoc:
-    project    = project.gsub(/([A-Z])/, '_\1').downcase.sub(/^_/, '')
+    project    = project.gsub(/([A-Z])/, '_\1').downcase.sub(/^_/, "")
     klass      = project.gsub(/(?:^|_)([a-z])/) { $1.upcase }
     klass      = klass.  gsub(/(?:^|-)([a-z])/) { "::#{$1.upcase}" }
     test_klass = klass.  gsub(/(^|::)([A-Z])/) { "#{$1}Test#{$2}" }
-    file_name  = project.gsub(/-/, '/')
+    file_name  = project.gsub(/-/, "/")
 
     return project, file_name, klass, test_klass
   end
@@ -399,14 +396,14 @@ class Hoe
 
   def activate_plugins
     with_config do |config, _|
-      config_plugins = config['plugins']
+      config_plugins = config["plugins"]
       break unless config_plugins
-      Hoe.plugins.concat config_plugins.map { |plugin| plugin.intern }
+      Hoe.plugins.concat config_plugins.map(&:intern)
     end
 
     Hoe.load_plugins Hoe.plugins
 
-    names = Hoe.constants.map { |s| s.to_s }
+    names = Hoe.constants.map(&:to_s)
     names.reject! { |n| n =~ /^[A-Z_]+$/ }
 
     names.each do |name|
@@ -474,8 +471,8 @@ class Hoe
     self.extra_dev_deps = normalize_deps extra_dev_deps
 
     case name
-    when 'hoe' then
-      dependency "rake", "~> 0.8"
+    when "hoe" then
+      dependency "rake", [">= 0.8", "< 11.0"]
     else
       version = VERSION.split(/\./).first(2).join(".")
       dependency "hoe", "~> #{version}", :development
@@ -502,7 +499,7 @@ class Hoe
   # Returns the proper dependency list for the thingy.
 
   def dependency_target
-    self.name == 'hoe' ? extra_deps : extra_dev_deps
+    self.name == "hoe" ? extra_deps : extra_dev_deps
   end
 
   ##
@@ -510,7 +507,7 @@ class Hoe
 
   def define_spec
     self.spec = Gem::Specification.new do |s|
-      dirs = Dir['lib']
+      dirs = Dir["lib"]
 
       manifest = read_manifest
 
@@ -518,7 +515,7 @@ class Hoe
              "Manifest is missing or couldn't be read.",
              "The Manifest is kind of a big deal.",
              "Maybe you're using a gem packaged by a linux project.",
-             "It seems like they enjoy breaking other people's code."
+             "It seems like they enjoy breaking other people's code.",
              ].join "\n" unless manifest
 
       s.name                 = name
@@ -533,15 +530,13 @@ class Hoe
                                else
                                  raise "unknown urls format: #{urls.inspect}"
                                end
-      s.rubyforge_project    = group_name
       s.description          = description
       s.files                = manifest
       s.executables          = s.files.grep(/^bin/) { |f| File.basename(f) }
       s.bindir               = "bin"
       s.require_paths        = dirs unless dirs.empty?
-      s.rdoc_options         = ['--main', readme_file]
+      s.rdoc_options         = ["--main", readme_file]
       s.post_install_message = post_install_message
-      s.test_files           = Dir[*self.test_globs].uniq
 
       missing "Manifest.txt" if s.files.empty?
 
@@ -571,24 +566,24 @@ class Hoe
   end
 
   def check_for_version # :nodoc:
+    return if self.version
+
+    version    = nil
+    version_re = /VERSION += +([\"\'])([\d][\w\.]+)\1/
+
+    spec.files.each do |file|
+      next unless File.exist? file
+      version = File.read_utf(file)[version_re, 2] rescue nil
+      break if version
+    end
+
+    spec.version = self.version = version if version
+
     unless self.version then
-      version    = nil
-      version_re = /VERSION += +([\"\'])([\d][\w\.]+)\1/
-
-      spec.files.each do |file|
-        next unless File.exist? file
-        version = File.read_utf(file)[version_re, 2] rescue nil
-        break if version
-      end
-
-      spec.version = self.version = version if version
-
-      unless self.version then
-        spec.version = self.version = "0.borked"
-        warn "** Add 'VERSION = \"x.y.z\"' to your code,"
-        warn "   add a version to your hoe spec,"
-        warn "   or fix your Manifest.txt"
-      end
+      spec.version = self.version = "0.borked"
+      warn "** Add 'VERSION = \"x.y.z\"' to your code,"
+      warn "   add a version to your hoe spec,"
+      warn "   or fix your Manifest.txt"
     end
   end
 
@@ -631,7 +626,7 @@ class Hoe
     self.author               = []
     self.changes              = nil
     self.description          = nil
-    self.description_sections = %w(description)
+    self.description_sections = %w[description]
     self.email                = []
     self.extra_deps           = []
     self.extra_dev_deps       = []
@@ -643,10 +638,12 @@ class Hoe
     self.spec_extras          = {}
     self.summary              = nil
     self.summary_sentences    = 1
-    self.test_globs           = ['test/**/{test,spec}_*.rb',
-                                 'test/**/*_{test,spec}.rb']
+    self.test_globs           = ["test/**/{test,spec}_*.rb",
+                                 "test/**/*_{test,spec}.rb"]
 
-    if manifest = read_manifest then
+    manifest = read_manifest
+
+    if manifest then
       self.readme_file  = manifest.grep(/^README\./).first
       self.history_file = manifest.grep(/^History\./).first
     end
@@ -662,11 +659,11 @@ class Hoe
 
   def intuit_values
     header_re = /^((?:=+|#+) .*)$/
-    readme    = File.read_utf(readme_file).split(header_re)[1..-1] rescue ''
+    readme    = File.read_utf(readme_file).split(header_re)[1..-1] rescue ""
 
     unless readme.empty? then
       sections = Hash[*readme.map { |s|
-        s =~ /^[=#]/ ? s.strip.downcase.chomp(':').split.last : s.strip
+        s =~ /^[=#]/ ? s.strip.downcase.chomp(":").split.last : s.strip
       }]
       desc     = sections.values_at(*description_sections).join("\n\n")
       summ     = desc.split(/\.\s+/).first(summary_sentences).join(". ")
@@ -684,7 +681,7 @@ class Hoe
                        h.split(/^(={2,}|\#{2,})/)[1..2].join.strip
                      rescue
                        missing history_file
-                       ''
+                       ""
                      end
   end
 
@@ -707,8 +704,7 @@ class Hoe
   # should update the readme.
 
   def parse_urls text
-
-    lines = text.gsub(/^\* /, '').delete("<>").split(/\n/).grep(/\S+/)
+    lines = text.gsub(/^\* /, "").delete("<>").split(/\n/).grep(/\S+/)
 
     if lines.first =~ /::/ then
       Hash[lines.map { |line| line.split(/\s*::\s*/) }]
@@ -785,7 +781,7 @@ class Hoe
 
   def pluggable!
     abort "update rubygems to >= 1.3.1" unless  Gem.respond_to? :find_files
-    require_rubygems_version '>= 1.3.1'
+    require_rubygems_version ">= 1.3.1"
   end
 
   ##
@@ -842,7 +838,7 @@ class Hoe
   # 12/31 of the current year.
 
   def timebomb n, m, finis = nil, start = nil
-    require 'time'
+    require "time"
     finis = Time.parse(finis || "#{Time.now.year}-12-31")
     start = Time.parse(start || "#{Time.now.year}-01-01")
     rest  = (finis - Time.now)
@@ -855,7 +851,7 @@ class Hoe
   # Verify that mandatory fields are set.
 
   def validate_fields
-    %w(email author).each do |field|
+    %w[email author].each do |field|
       value = self.send(field)
       abort "Hoe #{field} value not set. aborting" if value.nil? or value.empty?
     end
@@ -874,7 +870,7 @@ class Hoe
 
     config = config.merge homeconfig
 
-    localrc = File.join Dir.pwd, '.hoerc'
+    localrc = File.join Dir.pwd, ".hoerc"
     exists = File.exist? localrc
     localconfig = exists ? YAML.load_file(localrc) : {}
 
@@ -894,7 +890,7 @@ class File
       if r19 then
         f.read
       else
-        f.read.sub %r/\A\xEF\xBB\xBF/, ''
+        f.read.sub %r%\A\xEF\xBB\xBF%, ""
       end
     end
   end
