@@ -15,15 +15,15 @@ module Hoe::Clean
   # Initialize variables for plugin.
 
   def initialize_clean
-    self.clean_globs ||= %w(diff diff.txt TAGS ri deps .source_index
-                            *.gem **/*~ **/.*~ **/*.rbc coverage*)
+    self.clean_globs ||= %w[diff diff.txt TAGS ri deps .source_index
+                            *.gem **/*~ **/.*~ **/*.rbc coverage*]
   end
 
   ##
   # Define tasks for plugin.
 
   def define_clean_tasks
-    desc 'Clean up all the extras.'
+    desc "Clean up all the extras."
     task :clean => [ :clobber_docs, :clobber_package ] do
       clean_globs.each do |pattern|
         files = Dir[pattern]
