@@ -5,11 +5,10 @@ require "hoe/rake"
 #
 # === Tasks Provided:
 #
-# announce::           Create news email file and post to rubyforge.
+# announce::           Create news email file and optionally publish docs.
 # debug_email::        Generate email announcement file.
 # post_blog::          Post announcement to blog.
-# post_news::          Post announcement to rubyforge.
-# publish_docs::       Publish RDoc to RubyForge.
+# publish_docs::       Publish RDoc to `rdoc_locations`.
 # ridocs::             Generate ri locally for testing.
 #
 # === Extra Configuration Options:
@@ -63,7 +62,7 @@ module Hoe::Publish
   attr_accessor :rdoc_locations
 
   ##
-  # Optional: Name of RDoc destination directory on Rubyforge. [default: +name+]
+  # Optional: Name of RDoc destination directory. [default: +name+]
 
   attr_accessor :remote_rdoc_dir
 
@@ -80,9 +79,9 @@ module Hoe::Publish
                                     "url"      => "url",
                                     "blog_id"  => "blog_id",
                                     "extra_headers" => {
-                                      "mt_convert_breaks" => "markdown"
+                                      "mt_convert_breaks" => "markdown",
                                     },
-                                  }
+                                  },
                                  ]
 
   ##
@@ -90,11 +89,11 @@ module Hoe::Publish
 
   def initialize_publish
     self.blog_categories ||= [self.name]
-    self.local_rdoc_dir  ||= 'doc'
+    self.local_rdoc_dir  ||= "doc"
     self.need_rdoc       ||= true
     self.rdoc_locations  ||= []
     self.remote_rdoc_dir ||= self.name
-    self.rsync_args      ||= '-av -O --delete'
+    self.rsync_args      ||= "-av -O --delete"
   end
 
   ##
@@ -118,7 +117,7 @@ module Hoe::Publish
 
       desc "Generate rdoc coverage report"
       task :dcov => :isolate do
-        sh(*make_rdoc_cmd('-C'))
+        sh(*make_rdoc_cmd("-C"))
       end
 
       desc "Remove RDoc files"
@@ -128,9 +127,9 @@ module Hoe::Publish
 
       task :clobber => :clobber_docs
 
-      desc 'Generate ri locally for testing.'
+      desc "Generate ri locally for testing."
       task :ridocs => [:clean, :isolate] do
-        ruby(*make_rdoc_cmd('--ri', '-o', 'ri'))
+        ruby(*make_rdoc_cmd("--ri", "-o", "ri"))
       end
     end
 
@@ -144,7 +143,7 @@ module Hoe::Publish
       publish_on_announce_task
     end
 
-    desc 'Generate email announcement file.'
+    desc "Generate email announcement file."
     task :debug_email do
       puts generate_email
     end
@@ -154,47 +153,47 @@ module Hoe::Publish
       post_blog_task
     end
 
-    desc 'Announce your release.'
+    desc "Announce your release."
     task :announce => [:post_blog, :publish_on_announce ]
   end
 
   def publish_docs_task # :nodoc:
     warn "no rdoc_location values" if rdoc_locations.empty?
     self.rdoc_locations.each do |dest|
-      sh %{rsync #{rsync_args} #{local_rdoc_dir}/ #{dest}}
+      sh %(rsync #{rsync_args} #{local_rdoc_dir}/ #{dest})
     end
   end
 
   def publish_on_announce_task # :nodoc:
     with_config do |config, _|
-      Rake::Task['publish_docs'].invoke if config["publish_on_announce"]
+      Rake::Task["publish_docs"].invoke if config["publish_on_announce"]
     end
   end
 
   def post_blog_task # :nodoc:
-    with_config do |config, path|
-      break unless config['blogs']
+    with_config do |config, _path|
+      break unless config["blogs"]
 
-      config['blogs'].each do |site|
-        if site['path'] then
-          msg = "post_blog_#{site['type']}"
+      config["blogs"].each do |site|
+        if site["path"] then
+          msg = "post_blog_#{site["type"]}"
           send msg, site
           system site["cmd"] if site["cmd"]
         else
-          require 'xmlrpc/client'
+          require "xmlrpc/client"
 
           _, title, body, urls = announcement
           body += "\n\n#{urls}"
 
-          server = XMLRPC::Client.new2(site['url'])
-          content = site['extra_headers'].merge(:title => title,
+          server = XMLRPC::Client.new2(site["url"])
+          content = site["extra_headers"].merge(:title => title,
                                                 :description => body,
                                                 :categories => blog_categories)
 
-          server.call('metaWeblog.newPost',
-                      site['blog_id'],
-                      site['user'],
-                      site['password'],
+          server.call("metaWeblog.newPost",
+                      site["blog_id"],
+                      site["user"],
+                      site["password"],
                       content,
                       true)
         end
@@ -226,7 +225,7 @@ module Hoe::Publish
     Dir.chdir File.expand_path dir do
       time = Time.at Time.now.to_i # nukes fractions
       path = [time.strftime("%Y-%m-%d-"),
-              title.sub(/\W+$/, '').gsub(/\W+/, '-'),
+              title.sub(/\W+$/, "").gsub(/\W+/, "-"),
               ".html.md"].join
 
       header = {
@@ -236,7 +235,7 @@ module Hoe::Publish
       }
 
       File.open path, "w" do |f|
-        f.puts header.to_yaml.gsub(/\s$/, '')
+        f.puts header.to_yaml.gsub(/\s$/, "")
         f.puts "..."
         f.puts
         f.puts body
@@ -245,7 +244,7 @@ module Hoe::Publish
   end
 
   def generate_email full = nil # :nodoc:
-    require 'time'
+    require "time"
 
     abort "No email 'to' entry. Run `rake config_hoe` to fix." unless
       !full || email_to
@@ -258,9 +257,12 @@ module Hoe::Publish
      full && "To: #{email_to.join(", ")}",
      full && "Date: #{Time.now.rfc2822}",
      "Subject: [ANN] #{subject}",
-     "", title,
-     "", urls,
-     "", body,
+     "",
+     title,
+     "",
+     urls,
+     "",
+     body,
     ].compact.join("\n")
   end
 
@@ -273,14 +275,13 @@ module Hoe::Publish
     urls =
       case self.urls
       when Hash then
-        self.urls.map { |k,v| "* #{k}: <#{v.strip.rdoc_to_markdown}>" }
+        self.urls.map { |k, v| "* #{k}: <#{v.strip.rdoc_to_markdown}>" }
       when Array then
         self.urls.map { |s| "* <#{s.strip.rdoc_to_markdown}>" }
       else
         raise "unknown urls format: #{urls.inspect}"
       end
 
-
     return subject, title, body, urls.join("\n")
   end
 end
@@ -294,6 +295,6 @@ class String
   # Very basic munge from rdoc to markdown format.
 
   def rdoc_to_markdown
-    self.gsub(/^mailto:/, '').gsub(/^(=+)/) { "#" * $1.size }
+    self.gsub(/^mailto:/, "").gsub(/^(=+)/) { "#" * $1.size }
   end
 end
