@@ -3,7 +3,7 @@ require "hoe"
 
 Hoe.load_plugins # make sure Hoe::Test is loaded
 
-class TestHoeTest < MiniTest::Unit::TestCase
+class TestHoeTest < Minitest::Test
   def setup
     @tester = Module.new do
       include Hoe::Test
@@ -13,19 +13,24 @@ class TestHoeTest < MiniTest::Unit::TestCase
       initialize_test
 
       def test_globs
-        ['test/test_hoe_test.rb']
+        ["test/test_hoe_test.rb"]
       end
     end
   end
 
   def test_make_test_cmd_with_different_testlibs
-    skip "Using TESTOPTS... skipping" if ENV['TESTOPTS']
+    skip "Using TESTOPTS... skipping" if ENV["TESTOPTS"]
 
     expected = ['-w -Ilib:bin:test:. -e \'require "rubygems"; %s',
                 'require "test/test_hoe_test.rb"',
                 "' -- ",
                ].join
 
+    # default
+    autorun = %(require "minitest/autorun"; )
+    assert_equal expected % autorun, @tester.make_test_cmd
+
+    @tester.testlib = :testunit
     testunit = %(require "test/unit"; )
     assert_equal expected % testunit, @tester.make_test_cmd
 
